@@ -65,7 +65,6 @@ BooleanChoice[noskipws]:
 DocumentConfig[noskipws]:
   ('VERSION: ' version = /.*$/ '\n')?
   ('NUMBER: ' number = /.*$/ '\n')?
-  ('SPECIAL_FIELDS:' '\n' special_fields += ConfigSpecialField)?
 
   ('OPTIONS:' '\n'
     ('  MARKUP: ' (markup = MarkupChoice) '\n')?
@@ -73,12 +72,6 @@ DocumentConfig[noskipws]:
   )?
 ;
 
-ConfigSpecialField[noskipws]:
-'- NAME: ' field_name = /.*$/ '\n'
-'  TYPE: ' field_type = 'String' '\n'
-('  REQUIRED: ' field_required = 'Yes' '\n')?
-;
-
 MarkupChoice[noskipws]:
   'RST' | 'Text' | 'HTML'
 ;
@@ -130,20 +123,16 @@ RequirementType[noskipws]:
 ;
 
 RequirementField[noskipws]:
-  (
-    field_name = FieldName ':'
-    (
-      (' ' (field_value = SingleLineString) '\n') |
-      (' ' (field_value_multiline = MultiLineString) '\n')
-    )
-  ) |
   (
     field_name = 'REFS' ':' '\n'
     (field_value_references += Reference)
   ) |
   (
-    field_name = 'SPECIAL_FIELDS' ':' '\n'
-    field_value_special_fields += SpecialField
+    field_name = FieldName ':'
+    (
+      ((' ' field_value = SingleLineString | field_value = '') '\n') |
+      (' ' (field_value_multiline = MultiLineString) '\n')
+    )
   )
 ;
 
@@ -158,10 +147,6 @@ CompositeRequirement[noskipws]:
   '[/COMPOSITE_REQUIREMENT]' '\n'
 ;
 
-SpecialField[noskipws]:
-  '  ' field_name = /[A-Z][A-Z0-9_]+/ ': ' field_value = /.*$/ '\n'
-;
-
 ChoiceOption[noskipws]:
   /[\w\/-]+( *[\w\/-]+)*/
 ;
