@@ -1,11 +1,11 @@
 import collections
 
-from strictdoc.backend.dsl.models.document import Document
-from strictdoc.backend.dsl.models.requirement import (
+from strictdoc.backend.sdoc.models.document import Document
+from strictdoc.backend.sdoc.models.requirement import (
     CompositeRequirement,
     Requirement,
 )
-from strictdoc.backend.dsl.models.section import FreeText, Section
+from strictdoc.backend.sdoc.models.section import FreeText, Section
 from strictdoc.core.level_counter import LevelCounter
 
 
@@ -51,7 +51,12 @@ class DocumentCachingIterator:
                 assert current.ng_level, f"Node has no ng_level: {current}"
                 level_counter.adjust(current.ng_level)
 
-                current.context.title_number_string = level_counter.get_string()
+                # TODO: Remove the need to do branching here.
+                current.context.title_number_string = (
+                    current.level
+                    if current.level
+                    else level_counter.get_string()
+                )
 
             self.nodes_cache.append(current)
             yield current
