@@ -1,8 +1,7 @@
 from jinja2 import Environment, PackageLoader, StrictUndefined
 
-from strictdoc.backend.dsl.models.document import Document
+from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.export.html.document_type import DocumentType
-from strictdoc.export.html.renderers.markup_renderer import MarkupRenderer
 
 
 class DocumentHTMLGenerator:
@@ -13,25 +12,16 @@ class DocumentHTMLGenerator:
     env.globals.update(isinstance=isinstance)
 
     @staticmethod
-    def export(
+    def export(  # pylint: disable=too-many-arguments
         config,
-        document_tree,
         document: Document,
         traceability_index,
+        markup_renderer,
         link_renderer,
-        standalone=False,
+        standalone: bool,
     ):
-        document_type = DocumentType.document()
         output = ""
 
-        markup_renderer = MarkupRenderer.create(
-            document.config.markup,
-            traceability_index,
-            link_renderer,
-            document,
-            document_type,
-        )
-
         template = DocumentHTMLGenerator.env.get_template(
             "single_document/document.jinja.html"
         )
