@@ -20,7 +20,6 @@ class SourceFileViewHTMLGenerator:
     @staticmethod
     def export(
         source_file: SourceFile,
-        document_tree,
         traceability_index: TraceabilityIndex,
         link_renderer,
     ):
@@ -31,11 +30,11 @@ class SourceFileViewHTMLGenerator:
             "source_file_view/source_file_view.jinja.html"
         )
 
-        with open(source_file.full_path) as f:
-            source_file_lines = f.readlines()
+        with open(source_file.full_path, encoding="utf-8") as opened_file:
+            source_file_lines = opened_file.readlines()
 
         markup_renderer = MarkupRenderer.create(
-            "RST", traceability_index, link_renderer, None, document_type
+            "RST", traceability_index, link_renderer, None
         )
 
         lexer = None
